module.exports = defineTest({
	description: 'erroneous nested member expression does not mess up naming'
});
